@@ -1,7 +1,7 @@
 """ESA specific module."""
 
 from .juice import JUICE_CReMA
-from .crema import CReMAMetaKernel
+from .crema import CReMAMetaKernel, debug_esa_crema
 
 
 CReMAs = {
@@ -13,4 +13,5 @@ __all__ = [
     'CReMAs',
     'JUICE_CReMA',
     'CReMAMetaKernel',
+    'debug_esa_crema',
 ]
