@@ -50,7 +50,7 @@ class CReMACollection(type):
         return iter(cls.metakernels().values())
 
     def __contains__(cls, other):
-        return str(other) in cls.metakernels().keys()
+        return cls.key(other) in cls.metakernels().keys()
 
     def __getitem__(cls, key):
         return cls.get(key)
@@ -62,6 +62,11 @@ class CReMACollection(type):
     def __dict__(cls):
         return cls.__class__.__dict__
 
+    @staticmethod
+    def key(key):
+        """CReMA key formatter."""
+        return str(key).replace('_', '.').replace('-', ' ')
+
     # @property
     def metakernels(cls) -> dict:
         """Dict of available metakernels."""
@@ -117,7 +122,7 @@ class CReMACollection(type):
                                force_download=force_download)
 
         # Append/Update metakernels list
-        cls.__mk[str(meta)] = meta
+        cls.__mk[cls.key(meta)] = meta
 
         # Cache the data
         if cache:
@@ -143,10 +148,10 @@ class CReMACollection(type):
 
         """
         # Check if the key is valid
-        if str(key) not in cls:
+        if key not in cls:
             raise KeyError(f'Unknown {cls} `{key}`')
 
-        return cls.metakernels()[str(key)]
+        return cls.metakernels()[cls.key(key)]
 
     def remove(cls, key, cache=True, delete_file=False):
         """Remove CReMA metakernel.
@@ -167,7 +172,7 @@ class CReMACollection(type):
 
         """
         # Check if key exist
-        if str(key) not in cls:
+        if key not in cls:
             raise KeyError(f'Unknown {cls} `{key}`')
 
         # if requested delete the metakernel file
@@ -175,7 +180,7 @@ class CReMACollection(type):
             cls[key].fname.unlink()
 
         # Remove from metakernels list
-        del cls.__mk[str(key)]
+        del cls.__mk[cls.key(key)]
 
         # Remove from the cache
         if cache:
