@@ -1,12 +1,15 @@
 """Maps module."""
 
-from .map import CALLISTO, EUROPA, GANYMEDE, IO, Map
+from .map import CALLISTO, EARTH, EUROPA, GANYMEDE, MOON, IO, VENUS, Map
 
 
 __all__ = [
-    'IO',
+    'CALLISTO',
+    'EARTH',
     'EUROPA',
     'GANYMEDE',
-    'CALLISTO',
+    'MOON',
+    'IO',
+    'VENUS',
     'Map',
 ]
