@@ -138,7 +138,10 @@ DATA = Path(__file__).parent / 'data'
 
 
 # Mean radius from `pck00010.tpc` kernel
-IO = Map(DATA / 'Io.jpg', 'Io', radius=1821.5)
+CALLISTO = Map(DATA / 'Callisto.jpg', 'Callisto', radius=2410.3)
+EARTH = Map(DATA / 'Earth.jpg', 'Earth', radius=6371.0)
 EUROPA = Map(DATA / 'Europa.jpg', 'Europa', radius=1560.8)
 GANYMEDE = Map(DATA / 'Ganymede.jpg', 'Ganymede', radius=2631.2)
-CALLISTO = Map(DATA / 'Callisto.jpg', 'Callisto', radius=2410.3)
+MOON = Map(DATA / 'Moon.jpg', 'Moon', radius=1737.4)
+IO = Map(DATA / 'Io.jpg', 'Io', radius=1821.5)
+VENUS = Map(DATA / 'Venus.jpg', 'Venus', radius=6051.8)
