@@ -91,6 +91,11 @@ class ProjAxes(Axes):
             x, y = self.proj.xy_plot(*traj.lonlat)
             args = args[1:]
 
+        elif len(args) >= 2 and isinstance(args[0], (int, float)) \
+                and isinstance(args[1], (int, float)):
+            x, y = self.proj.xy_plot([args[0]], [args[1]])
+            args = args[2:]
+
         elif len(args[0]) == 2 and isinstance(args[0], (tuple, list)) \
                 and np.ndim(args[0]) == 2:
             x, y = self.proj.xy_plot(*args[0])
