@@ -29,7 +29,7 @@ class Stephan2020ROIsCollection(ROIsCollectionWithCategories):
 
     """
 
-    def __init__(self, *args, csv=None, prefix=None, **kwargs):
+    def __init__(self, *args, csv=None, prefix=None, target=None, **kwargs):
         super().__init__(*args, **kwargs)
 
         if csv is None:
@@ -41,6 +41,7 @@ class Stephan2020ROIsCollection(ROIsCollectionWithCategories):
             raise FileNotFoundError(self.csv)
 
         self.prefix = prefix
+        self.target = str(target)
 
         self.load_csv()
 
@@ -128,9 +129,10 @@ class Stephan2020ROIsCollection(ROIsCollectionWithCategories):
 
             if cat.startswith('#'):
                 if subcat == '0':
-                    self.add_category(key, **attrs, color=roi)
+                    self.add_category(key, **attrs, color=roi, target=self.target)
                 else:
-                    self.add_subcategory(key, **attrs, category=cat[2:], color=roi)
+                    self.add_subcategory(key, **attrs, category=cat[2:], color=roi,
+                                         target=self.target)
 
             else:
                 if subcat == '0':
@@ -138,6 +140,7 @@ class Stephan2020ROIsCollection(ROIsCollectionWithCategories):
                     cat_attrs = {
                         'category': category,
                         'color': category.color,
+                        'target': category.target,
                     }
                 else:
                     subcategory = self.subcategories[self.key(cat=cat, subcat=subcat)]
@@ -145,6 +148,7 @@ class Stephan2020ROIsCollection(ROIsCollectionWithCategories):
                         'category': subcategory.category,
                         'subcategory': subcategory,
                         'color': subcategory.category.color,
+                        'target': subcategory.category.target,
                     }
 
                 lons_e = np.array([min_lon_e, max_lon_e, max_lon_e, min_lon_e],
@@ -158,10 +162,12 @@ class Stephan2020ROIsCollection(ROIsCollectionWithCategories):
 GanymedeROIs = Stephan2020ROIsCollection(
     csv=DATA / 'Ganymede_ROIs-Stephan_2020_PSS-Tab_2.csv',
     prefix='JUICE_ROI_GAN_',
+    target='Ganymede',
 )
 
 # Callisto ROIs from K. Stephan et al., PSS (2020) [under review] - Tab. 3.
 CallistoROIs = Stephan2020ROIsCollection(
     csv=DATA / 'Callisto_ROIs-Stephan_2020_PSS-Tab_3.csv',
     prefix='JUICE_ROI_CAL_',
+    target='Callisto',
 )
