@@ -2,12 +2,15 @@
 
 from .pool import SPICEPool, debug_spice_pool
 from .references import SPICERef
-from .times import et, et_range, utc
+from .times import et, et_ca_range, et_range, et_ranges, tdb, utc
 
 
 __all__ = [
     'et',
     'et_range',
+    'et_ranges',
+    'et_ca_range',
+    'tdb',
     'utc',
     'SPICERef',
     'SPICEPool',
