@@ -1,5 +1,7 @@
 """SPICE reference module."""
 
+import numpy as np
+
 import spiceypy as sp
 from spiceypy.utils.exceptions import SpiceKERNELVARNOTFOUND
 
@@ -91,6 +93,32 @@ class SPICERef:
             raise KeyError(
                 f'This body `{self}` does not have a RADII attribute.') from None
 
+    @property
+    def radius(self):
+        """Body mean radius, if available (km)."""
+        return np.cbrt(np.product(self.radii))
+
+    @property
+    def r(self):
+        """Body mean radius alias."""
+        return self.radius
+
+    @property
+    def re(self):
+        """Body equatorial radius, if available (km)."""
+        return self.radii[0]
+
+    @property
+    def rp(self):
+        """Body polar radius, if available (km)."""
+        return self.radii[2]
+
+    @property
+    def f(self):
+        """Body flattening coefficient, if available (km)."""
+        re, _, rp = self.radii
+        return (re - rp) / re
+
     @property
     def mu(self):
         """Gravitational parameter (GM, km³/sec²)."""
