@@ -1,6 +1,8 @@
-"""Trajectory calculation configuration module."""
+"""Tour configuration module."""
 
-from .trajectory import Trajectory
+import numpy as np
+
+from .trajectory import Flyby, Trajectory, log_traj
 
 from ..esa import CReMAs
 from ..kernels import MetaKernel, Kernels
@@ -8,8 +10,8 @@ from ..kernels.kernel import KernelsDirectoryNotFoundError
 from ..spice import SPICEPool, et_range
 
 
-class TrajectoryConfig:
-    """Trajectory calculation configuration object.
+class TourConfig:
+    """Orbital tour configuration object.
 
     Prepare the kernels configuration based on the selected
     spacecraft, target and metakernel setup.
@@ -94,19 +96,33 @@ class TrajectoryConfig:
             f'Target: {self.target}'
         )
 
-    def __getitem__(self, value):
-        if isinstance(value, slice):
-            value = et_range(
-                value.start,
-                value.stop,
-                value.step if value.step is not None else self.default_time_step,
-            )
+    def __getitem__(self, ets):
+        if ets is None:
+            ets = 'all'
+
+        if isinstance(ets, str) and ets in ['all', 'complete', 'full']:
+            ets = slice(*self.coverage, '30 mins')
+
+        if isinstance(ets, slice):
+            start = ets.start \
+                if ets.start not in [None, 'start', 'beg', 'begin', 'begining'] else \
+                self.coverage[0]
+
+            stop = ets.stop \
+                if ets.stop not in [None, 'stop', 'end'] else \
+                self.coverage[1]
+
+            step = ets.step \
+                if ets.step is not None else \
+                self.default_time_step
+
+            ets = et_range(start, stop, step)
 
         return Trajectory(
             self.kernels,
             self.spacecraft,
             self.target,
-            value,
+            ets,
         )
 
     @property
@@ -191,3 +207,62 @@ class TrajectoryConfig:
         """Load the kernels in the SPICE pool."""
         if SPICEPool != self.kernels:
             SPICEPool.add(self.kernels, purge=True)
+
+    @property
+    def coverage(self):
+        """Observer and Target intersection coverage.
+
+        Overlaping windows of coverage from the observer
+        and target data loaded in the SPICE pool.
+
+        """
+        start, stop = SPICEPool.coverage(self.spacecraft, self.target)
+
+        # Fix rounding issues
+        start += np.timedelta64(1, 'ms')
+        stop -= np.timedelta64(1, 'ms')
+
+        return start, stop
+
+    @property
+    def flybys(self):
+        """List of all the flybys on the target."""
+        return self['all'].flybys
+
+    def flyby(self, approx_ca_date, *dt):
+        """Select a single flyby with an approximate date.
+
+        Parameters
+        ----------
+        approx_ca_date: float, string or numpy.datetime64
+            Approximate CA datetime (at day level).
+            This value will be re-computed (at the second level).
+
+        *dt: tuple(s), optional
+            Temporal sequence around closest approach:
+
+            `(duration, numpy.datetime unit, step value and unit)`
+
+            See :py:func:`moon_coverage.spice.et_ca_range` for more details.
+
+        Returns
+        -------
+        moon_coverage.trajectory.Flyby
+
+        """
+        return Flyby(
+            self.kernels,
+            self.spacecraft,
+            self.target,
+            approx_ca_date,
+            *dt,
+        )
+
+
+class TrajectoryConfig(TourConfig):
+    """Tour configuration old alias."""
+    def __init__(self, **kwargs):
+        log_traj.warning('`TrajectoryConfig` class was renamed `TourConfig`. '
+                         'Please update your code to use this new denomination.')
+
+        super().__init__(**kwargs)
