@@ -67,9 +67,9 @@ class MaskedTrajectory:  # pylint: disable=too-many-public-methods
             f'<{self.__class__.__name__}> '
             f'Observer: {self.observer} | '
             f'Target: {self.target}'
-            f'\n - First start time: {self.start}'
-            f'\n - Last stop time: {self.stop}'
-            f'\n - Nb of pts: {len(self)} (+{self.nb_masked} masked)'
+            f'\n - First UTC start time: {self.start}'
+            f'\n - Last UTC stop time: {self.stop}'
+            f'\n - Nb of pts: {len(self):,d} (+{self.nb_masked:,d} masked)'
             f'\n - Nb of segments: {self.nb_segments}'
         )
 
@@ -101,23 +101,23 @@ class MaskedTrajectory:  # pylint: disable=too-many-public-methods
 
     @property
     def starts(self):
-        """Start time segments."""
+        """UTC start time segments."""
         return self.utc[self.seg.istarts]
 
     @property
     def stops(self):
-        """Stop time segments."""
+        """UTC stop time segments."""
         return self.utc[self.seg.istops]
 
     @property
     def start(self):
-        """Start time of the initial segment."""
-        return self.starts[0] if len(self) != 0 else None
+        """UTC start time of the initial segment."""
+        return self.starts[0] if len(self) != 0 else np.datetime64('NaT')
 
     @property
     def stop(self):
-        """Stop time of the last segment."""
-        return self.stops[-1] if len(self) != 0 else None
+        """UTC stop time of the last segment."""
+        return self.stops[-1] if len(self) != 0 else np.datetime64('NaT')
 
     @property
     def windows(self):
@@ -142,7 +142,7 @@ class MaskedTrajectory:  # pylint: disable=too-many-public-methods
 
     @masked_trajectory_property
     def lonlat(self):
-        """Masked sub-observer ground track coordinates (degree)."""
+        """Masked sub-observer ground track east longitudes and latitudes (degree)."""
 
     @masked_trajectory_property
     def local_time(self):
