@@ -6,7 +6,7 @@ from .mask_traj import MaskedTrajectory
 
 from ..math.vectors import angle, norm, ell_norm
 from ..misc import cached_property, logger
-from ..spice import SPICEPool, SPICERef, et, et_range, utc
+from ..spice import SPICEPool, SPICERef, et, et_range, et_ca_range, utc
 from ..spice.toolbox import (
     illum_angles, groundtrack_velocity, local_time, obs_state,
     rlonlat, solar_longitude, sub_obs_pt, sun_pos, true_anomaly
@@ -27,7 +27,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
     observer: str or spice.SPICERef
         Observer SPICE reference.
 
-    observer: str or spice.SPICERef
+    target: str or spice.SPICERef
         Target SPICE reference.
 
     ets: float or str or list
@@ -46,8 +46,8 @@ class Trajectory:  # pylint: disable=too-many-public-methods
         self.kernels = kernels
 
         # Init SPICE references
-        self.observer = observer if isinstance(observer, SPICERef) else SPICERef(observer)
-        self.target = target if isinstance(target, SPICERef) else SPICERef(target)
+        self.observer = SPICERef(observer)
+        self.target = SPICERef(target)
 
         # Init ephemeris times
         self.ets = ets
@@ -60,9 +60,9 @@ class Trajectory:  # pylint: disable=too-many-public-methods
             f'<{self.__class__.__name__}> '
             f'Observer: {self.observer} | '
             f'Target: {self.target}'
-            f'\n - Start time: {self.start}'
-            f'\n - Stop time: {self.stop}'
-            f'\n - Nb of pts: {len(self)}'
+            f'\n - UTC start time: {self.start}'
+            f'\n - UTC stop time: {self.stop}'
+            f'\n - Nb of pts: {len(self):,d}'
         )
 
     def __len__(self):
@@ -205,7 +205,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
         -------
         np.ndarray
             Sub-observer planetocentric coordinates:
-            radii, east longitudes and longitudes.
+            radii, east longitudes and latitudes.
 
         Note
         ----
@@ -234,7 +234,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
     @property
     def lonlat(self):
-        """Sub-observer ground track (degree)."""
+        """Sub-observer ground track east longitudes and latitudes (degree)."""
         return self.sub_obs_rlonlat[1:]
 
     @cached_property(parent='sub_obs_rlonlat')
@@ -596,3 +596,273 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         cond = obj.contains(self.lonlat)
         return cond if outside else ~cond
+
+    @property
+    def approx_ca_utc(self):
+        """List of approximate closest approach UTC times to the target.
+
+        Warning
+        -------
+        These values may not be accurate depending on the
+        :py:class:`Trajectory` temporal resolution.
+
+        """
+        return [
+            self.utc[seg][np.argmin(self.dist[seg])]
+            # pylint: disable=comparison-with-callable
+            for seg in self.where(self.dist <= Flyby.DIST_MIN).seg
+        ]
+
+    @property
+    def flybys(self):
+        """Get all the flybys for this trajectory."""
+        return [
+            Flyby(self.kernels, self.observer, self.target, ca_utc, abcorr=self.abcorr)
+            for ca_utc in self.approx_ca_utc
+        ]
+
+
+class Flyby(Trajectory):
+    """Trajectory flyby object.
+
+    The location of the closest approach point is
+    recomputed internally to ensure that the flyby is correctly
+    center on its lowest altitude with a resolution of 1 sec.
+
+    To ensure better performances, the CA location is found
+    in a 3 steps process:
+
+    - 1st stage with a coarse resolution (20 min at CA ± 12h)
+    - 2nd stage with a medium resolution (1 min at CA ± 30 min)
+    - 3rd stage with a fine resolution (1 sec at CA ± 2 min)
+
+    By default the final sampling temporal steps are irregular
+    with a high resolution only around the CA:
+
+    - 1 pt from CA -12 h to CA  -2 h every 10 min
+    - 1 pt from CA  -2 h to CA  -1 h every  1 min
+    - 1 pt from CA  -1 h to CA -10 m every 10 sec
+    - 1 pt from CA -10 m to CA +10 m every  1 sec
+    - 1 pt from CA +10 m to CA  +1 h every 10 sec
+    - 1 pt from CA  +1 h to CA  +2 h every  1 min
+    - 1 pt from CA  +2 h to CA +12 h every 10 min
+
+    = ``2,041 points`` around the CA point.
+
+    Parameters
+    ----------
+    kernels: str or tuple
+        List of kernels to be loaded in the SPICE pool.
+
+    observer: str or spice.SPICERef
+        Observer SPICE reference.
+
+    target: str or spice.SPICERef
+        Target SPICE reference.
+
+    approx_ca_utc: float, string or numpy.datetime64
+        Approximate CA datetime. This value will be re-computed.
+
+    *dt: tuple(s), optional
+        Temporal sequence around closest approach:
+
+        `(duration, numpy.datetime unit, step value and unit)`
+
+        See :py:func:`moon_coverage.spice.et_ca_range` for more details.
+
+    abcorr: str, optional
+        Aberration corrections to be applied when computing
+        the target's position and orientation.
+        Only the SPICE keys are accepted.
+
+    See Also
+    --------
+    Trajectory
+    moon_coverage.spice.et_ca_range
+
+    Raises
+    ------
+    AltitudeTooHighError
+        If the target altitude is too high (above ``100,000 km``)
+
+    """
+
+    DIST_MIN = 100_000  # Distance minimal to a given target [km]
+
+    def __init__(self, kernels, observer, target, approx_ca_utc, *dt, abcorr='NONE'):
+        # Check the pool coverage
+        et_min, et_max = SPICEPool.coverage(observer, target, fmt='ET')
+
+        # Coarse stage
+        coarse_ets = et_ca_range(approx_ca_utc, (24, 'h', '20 min'))
+        coarse_ets = coarse_ets[(et_min <= coarse_ets) & (coarse_ets <= et_max)]
+
+        log_traj.info('Coarse UTC window: %s', utc(coarse_ets[0], coarse_ets[-1]))
+
+        coarse_traj = Trajectory(kernels, observer, target, coarse_ets)
+        coarse_ca_utc = coarse_traj.utc[np.argmin(coarse_traj.dist)]
+
+        log_traj.info('Coarse CA UTC: %s', coarse_ca_utc)
+
+        # Medium stage
+        medium_ets = et_ca_range(coarse_ca_utc, (30, 'm', '1 min'))
+        medium_ets = medium_ets[(et_min <= medium_ets) & (medium_ets <= et_max)]
+
+        log_traj.info('Medium UTC window: %s', utc(medium_ets[0], medium_ets[-1]))
+
+        medium_traj = Trajectory(kernels, observer, target, medium_ets)
+        medium_ca_utc = medium_traj.utc[np.argmin(medium_traj.dist)]
+
+        log_traj.info('Medium CA UTC: %s', medium_ca_utc)
+
+        # Fine stage
+        fine_ets = et_ca_range(medium_ca_utc, (2, 'm', '1 sec'))
+        fine_ets = fine_ets[(et_min <= fine_ets) & (fine_ets <= et_max)]
+
+        log_traj.info('Fine UTC window: %s', utc(fine_ets[0], fine_ets[-1]))
+
+        fine_traj = Trajectory(kernels, observer, target, fine_ets)
+        fine_ca_utc = fine_traj.utc[np.argmin(fine_traj.alt)]
+
+        # Round [ms] digits to 1 sec precision
+        fine_ca_utc = (fine_ca_utc + np.timedelta64(500, 'ms')).astype('datetime64[s]')
+
+        log_traj.info('Fine CA UTC: %s', fine_ca_utc)
+
+        # Check min altitude to make sure its valid flyby
+        fine_ca_alt = fine_traj.alt[np.argmin(fine_traj.alt)]
+
+        if fine_ca_alt > self.DIST_MIN:
+            raise AltitudeTooHighError(
+                f'{fine_ca_alt:,.1f} km > {self.DIST_MIN:,.1f} km at CA')
+
+        # Select the flyby temporal grid
+        ets = et_ca_range(fine_ca_utc, *dt)
+        ets = ets[(et_min <= ets) & (ets <= et_max)]
+
+        super().__init__(kernels, observer, target, ets)
+
+    def __repr__(self):
+        return (
+            f'<{self.__class__.__name__}> '
+            f'Observer: {self.observer} | '
+            f'Target: {self.target}'
+            f'\n - Altitude at CA: {self.alt_ca:,.1f} km'
+            f'\n - UTC at CA: {self.utc_ca}'
+            f'\n - Duration: {self.duration}'
+            f'\n - Nb of pts: {len(self):,d}'
+        )
+
+    @property
+    def duration(self):
+        """Flyby duration."""
+        return (self.stop - self.start).item()
+
+    @cached_property
+    def _i_ca(self):
+        """Closest approach index."""
+        return np.argmin(self.alt)
+
+    @property
+    def et_ca(self):
+        """Closest approach ET time."""
+        return self.ets[self._i_ca]
+
+    @property
+    def utc_ca(self):
+        """Closest approach UTC time."""
+        return self.utc[self._i_ca].astype('datetime64[s]')
+
+    @property
+    def date_ca(self):
+        """Closest approach date."""
+        return np.datetime64(self.utc_ca, 'D')
+
+    @property
+    def t_ca(self):
+        """Time to closest approach."""
+        return (self.utc - self.utc_ca).astype('timedelta64[s]')
+
+    @property
+    def lon_e_ca(self):
+        """Sub-observer west longitude at closest approach."""
+        return self.sub_obs_lon_e[self._i_ca]
+
+    @property
+    def lat_ca(self):
+        """Sub-observer latitude at closest approach."""
+        return self.sub_obs_lat[self._i_ca]
+
+    @property
+    def alt_ca(self):
+        """Altitude at closest approach (km)."""
+        return self.alt[self._i_ca]
+
+    @cached_property
+    def ca(self):
+        """Closest approach point."""
+        return Trajectory(self.kernels, self.observer, self.target, self.et_ca)
+
+    @staticmethod
+    def _interp(alt, alts, ets):
+        """Interpolate UTC time for a given altitude."""
+        if len(ets) > 1:
+            if alt < alts.min():
+                raise AltitudeTooLowError(f'{alt:,.1f} km < {alts.min():,.1f} km at CA')
+
+            if alt > alts.max():
+                raise AltitudeTooHighError(f'{alt:,.1f} km > {alts.max():,.1f} km at CA')
+
+            if np.sum(alts[1:] >= alts[:-1]) != len(alts) - 1:
+                raise ValueError('The function is not strictly increasing.')
+
+            et_alt = np.interp(alt, alts, ets)
+        else:
+            et_alt = ets[0]
+
+        return utc(et_alt, unit='s')
+
+    @property
+    def inbound(self):
+        """Inbound part of the flyby, before CA."""
+        return slice(self._i_ca, None, -1)
+
+    @property
+    def outbound(self):
+        """Outbound part of the flyby, after CA."""
+        return slice(self._i_ca, None)
+
+    def alt_window(self, alt):
+        """Interpolated altitude window during the flyby.
+
+        Parameters
+        ----------
+        alt: float
+            Altitude reach to start and stop the window (in km).
+
+        Return
+        ------
+        numpy.datetime64, numpy.datetime64, numpy.timedelta64
+            UTC start, stop times and duration.
+
+        Raises
+        ------
+        AltitudeTooLowError
+            If the altitude provided is lower than the CA altitude.
+        AltitudeTooHighError
+            If the altitude provided is higher than the
+            max altitude of the flyby.
+
+        """
+        start = self._interp(alt, self.alt[self.inbound], self.ets[self.inbound])
+        stop = self._interp(alt, self.alt[self.outbound], self.ets[self.outbound])
+
+        return start, stop, (stop - start).item()
+
+
+class AltitudeTooLowError(Exception):
+    """Min value is too low and never reach during the flyby."""
+
+
+class AltitudeTooHighError(Exception):
+    """Min value is too high and not sampled during the flyby."""
